from setuptools import setup


setup(
      name='gymconnectx',
      version='1.0.1',
      description='ConnectX is a game for two players that is based on the well-known Connect 4. The goal is to place X coins in a row, column, or diagonal on a board with dimensions M by N.',
      url='https://github.com/fauzisho/GymConnectX',
      author='Fauzi Sholichin',
      license='MIT License',
      install_requires=['gym','pygame','numpy']
)